==> clms.downloadtool-0.7.zip: clms.downloadtool-0.7/src/clms/downloadtool/api/services/datarequest_delete/delete.py <==
# -*- coding: utf-8 -*-
"""
For HTTP GET operations we can use standard HTTP parameter passing
(through the URL)

"""
from logging import getLogger

from plone.restapi.services import Service
from plone.restapi.deserializer import json_body
from plone import api
from zope.component import getUtility
from clms.downloadtool.utility import IDownloadToolUtility

# logger, do log.info('XXXX') to print in the console

log = getLogger(__name__)


class datarequest_delete(Service):
    """Delete data
    """
    def reply(self):
        """ JSON response """
        body = json_body(self.request)
        user_id = api.user.get_current()
        task_id = str(body.get("TaskID"))
        response_json = None
        log.info("DATAREQUEST_DELETE")
        utility = getUtility(IDownloadToolUtility)

        if not task_id:
            self.request.response.setStatus(400)
            return {"status": "error", "msg": "Error, TaskID not defined"}
        if not user_id:
            self.request.response.setStatus(400)
            return {"status": "error", "msg": "Error, UserID not defined"}

        response_json = utility.datarequest_delete(task_id, user_id)

        if "Error, TaskID not registered" in response_json:
            self.request.response.setStatus(403)
            return {"status": "error", "msg": response_json}

        if "Error, permission denied" in response_json:
            self.request.response.setStatus(404)
            return {"status": "error", "msg": response_json}

        self.request.response.setStatus(204)
        return response_json

==> clms.downloadtool-1.2.zip: clms.downloadtool-1.2/src/clms/downloadtool/api/services/datarequest_delete/delete.py <==
# -*- coding: utf-8 -*-
"""
For HTTP GET operations we can use standard HTTP parameter passing
(through the URL)

"""
from logging import getLogger

from plone.restapi.services import Service
from plone.restapi.deserializer import json_body
from plone import api
from zope.component import getUtility
from clms.downloadtool.utility import IDownloadToolUtility

# logger, do log.info('XXXX') to print in the console

log = getLogger(__name__)


class datarequest_delete(Service):
    """Delete data"""

    def reply(self):
        """ JSON response """
        body = json_body(self.request)
        user = api.user.get_current()
        user_id = user.getId()
        task_id = str(body.get("TaskID"))
        response_json = None
        log.info("DATAREQUEST_DELETE")
        utility = getUtility(IDownloadToolUtility)

        if not task_id:
            self.request.response.setStatus(400)
            return {"status": "error", "msg": "Error, TaskID not defined"}
        if not user_id:
            self.request.response.setStatus(400)
            return {"status": "error", "msg": "Error, UserID not defined"}

        response_json = utility.datarequest_delete(task_id, user_id)

        if "Error, TaskID not registered" in response_json:
            self.request.response.setStatus(403)
            return {"status": "error", "msg": response_json}

        if "Error, permission denied" in response_json:
            self.request.response.setStatus(404)
            return {"status": "error", "msg": response_json}

        self.request.response.setStatus(204)
        return response_json
